summaryrefslogtreecommitdiffhomepage
path: root/mullvad-cli/src/cmds
diff options
context:
space:
mode:
authorJoakim Hulthe <joakim.hulthe@mullvad.net>2024-09-09 10:20:31 +0200
committerJoakim Hulthe <joakim.hulthe@mullvad.net>2024-09-17 11:29:36 +0200
commitcd78ee2663ad8effcd639a07050e948cabee2416 (patch)
treef5e6e907d25f148ca2442eedd7d7a64e84cd39da /mullvad-cli/src/cmds
parentdb82d8936172a82ef82c206f2bcf47ef099c302f (diff)
downloadmullvadvpn-cd78ee2663ad8effcd639a07050e948cabee2416.tar.xz
mullvadvpn-cd78ee2663ad8effcd639a07050e948cabee2416.zip
Align Smart routing GUI with design spec
Diffstat (limited to 'mullvad-cli/src/cmds')
-rw-r--r--mullvad-cli/src/cmds/tunnel.rs17
1 files changed, 9 insertions, 8 deletions
diff --git a/mullvad-cli/src/cmds/tunnel.rs b/mullvad-cli/src/cmds/tunnel.rs
index c17877b438..da66cac5d5 100644
--- a/mullvad-cli/src/cmds/tunnel.rs
+++ b/mullvad-cli/src/cmds/tunnel.rs
@@ -41,9 +41,9 @@ pub enum TunnelOptions {
/// Configure whether to enable DAITA
#[arg(long)]
daita: Option<BooleanOption>,
/// Configure whether to enable DAITA "use anywhere"
#[arg(long)]
- daita_use_anywhere: Option<BooleanOption>,
+ daita_smart_routing: Option<BooleanOption>,
/// The key rotation interval. Number of hours, or 'any'
#[arg(long)]
rotation_interval: Option<Constraint<RotationInterval>>,
@@ -138,7 +138,7 @@ impl Tunnel {
mtu,
quantum_resistant,
daita,
- daita_use_anywhere,
+ daita_smart_routing,
rotation_interval,
rotate_key,
} => {
@@ -146,7 +146,7 @@ impl Tunnel {
mtu,
quantum_resistant,
daita,
- daita_use_anywhere,
+ daita_smart_routing,
rotation_interval,
rotate_key,
)
@@ -178,7 +178,7 @@ impl Tunnel {
mtu: Option<Constraint<u16>>,
quantum_resistant: Option<QuantumResistantState>,
daita: Option<BooleanOption>,
- daita_use_anywhere: Option<BooleanOption>,
+ daita_smart_routing: Option<BooleanOption>,
rotation_interval: Option<Constraint<RotationInterval>>,
rotate_key: Option<RotateKey>,
) -> Result<()> {
@@ -197,11 +197,12 @@ impl Tunnel {
if let Some(enable_daita) = daita {
rpc.set_enable_daita(*enable_daita).await?;
println!("DAITA setting has been updated");
+ println!("Smart routing setting has been updated");
}
- if let Some(daita_use_anywhere) = daita_use_anywhere {
- rpc.set_daita_use_anywhere(*daita_use_anywhere).await?;
- println!("DAITA setting has been updated");
+ if let Some(daita_smart_routing) = daita_smart_routing {
+ rpc.set_daita_smart_routing(*daita_smart_routing).await?;
+ println!("Smart routing setting has been updated");
}
if let Some(interval) = rotation_interval {
@@ -41,9 +41,9 @@ pub enum TunnelOptions {
#[arg(long)]
daita: Option<BooleanOption>,
- /// Configure whether to enable DAITA "use anywhere"
+ /// Configure whether to enable DAITA smart routing
#[arg(long)]